#!/usr/bin/env python

import sys
import math
import numpy as np
import pyterpol

cm = 1.e-2		# m
nm = 1.e-9		# m
Ang = 1.e-10		# m
erg = 1.e-7		# J
c_ = 299792458.		# m s^-1
h = 6.63e-34		# J s
k = 1.38e-23		# J K^-1

def B(lambda_,T):
    return 2.*h*c_**2/lambda_**5 * 1. / (np.exp(h*c_/(k*T*lambda_)) - 1)

day = 86400.  # s
km = 1.e3  # m
R_S = 6.957e8  # m
M_S = 1.99e30  # kg
G = 6.67408e-11  # SI

P0 = 12.913779*day
P2 = P0
R2 = 19.84*R_S
M2 = 2.9*M_S
g2 = G*M2/R2**2
T2 = 13300.
logg2 = math.log10(g2/cm)
vrot2 = 2.*math.pi*R2/P2 / km

R2_eq = 3./2.*R2
g2_eq = G*M2/R2_eq**2
T2_eq = T2 * (g2_eq/g2)**0.25

print "logg2 = ", logg2, " [cgs]"
print "vrot2 = ", vrot2, " km s^-1"
print "T2 = ", T2, " K (polar)"
print "T2_eq = ", T2_eq, " K"

sg = pyterpol.SyntheticGrid(flux_type="absolute")

# we need UNROTATED spectra for shellspec
vrots = [0.0]
names = ['starspec2']
wlim = [900., 20000.]

Temp = range(10000,14200,200)
print Temp

name = names[0]
fout = open(name, "w")
fout.write("#ntemp, number of different temperatures of the models\n")
fout.write("%d\n" % (len(Temp)))
fout.write("#temperatures [K], one per line\n")
for T in Temp:
    fout.write("%.0f\n" % (T))
fout.write("#file names with spectra for each temperature, one per line\n")
for T in Temp:
    fout.write("pyterpol/" + name + "_" + str(int(T)) + ".abs\n")
fout.close()

for T in Temp:

    seco = dict(teff=T, logg=logg2,  z=1.0)

    for vrot, comp, name in zip(vrots, [seco], names):

        c = sg.get_synthetic_spectrum(comp, wlim, order=4, step=1.0, padding=0.0)
        c.get_spectrum(vrot=vrot, keep=True)
#        c.write_spectrum(filename=name + '.abs')

        fout = open(name + "_" + str(int(T)) + ".abs", "w")
        for i in xrange(0,len(c.wave)):
           fout.write("%12.6f %12.8e\n" % (c.wave[i], c.intens[i]/(4.*math.pi)))

        # extrapolation
        step = 10.0
        wmin = 20000. + step
        wmax = 48000.
        n = int((wmax-wmin)/step)+1

        factor = c.intens[-1] / (np.pi * B(c.wave[-1]*Ang, T) / (erg*cm**(-2)*Ang**(-1)))

        for i in xrange(0,n):
           wave = wmin + i*step
           intens = np.pi * B(wave*Ang, T)  / (erg*cm**(-2)*Ang**(-1)) / (4.*np.pi)*factor 

           fout.write("%12.6f %12.8e\n" % (wave, intens))

        fout.close()



